
include	\Projects\GdipTest\GdiPlusFunc.inc

;--------------------------------------------------------------------------------

.code

;--------------------------------------------------------------------------------

InitializeGdiPlus proc hWnd:DWORD
	
COMMENT	^----------------------------------------------------------------------
;PURPOSE:	initialize gdiplus
;IN		:	n/a
;OUT	:	success	-	GpStatusOk
;		:	fail	-	one of other values in the Status enum structure
;RETURN	:	eax
comment	----------------------------------------------------------------------^
	
	LOCAL	@gdiplusstartupinput	:GdiplusStartupInput

	invoke	RtlZeroMemory, addr @gdiplusstartupinput, sizeof GdiplusStartupInput
	mov		@gdiplusstartupinput.GdiplusVersion, 1
	
	invoke GdiplusStartup, addr _pGdiPlusToken, addr @gdiplusstartupinput, NULL

	invoke CreateGdiPlusFontFamily,addr _szGdiPlusFontFamilyName,addr _hGdiPlusFontFamily

	invoke CreateGdiPlusFont,_hGdiPlusFontFamily, addr _hGdiPlusFont

	invoke MakeARGB,0FFh,64,64,64
	invoke CreateGdiPlusSolidBrush,eax,addr _hGdiPlusSolidBrush
	invoke CreateGdiPlusPenFromBrush,_hGdiPlusSolidBrush,1,addr _hGdiPlusPen
	
	invoke CreateGdiPlusStringFormat,StringFormatFlagsDirectionRightToLeft ,addr _hGdiPlusStringFormat
	
	invoke CreateGdiPlusGraphics,hWnd

	ret

InitializeGdiPlus endp
;--------------------------------------------------------------------------------

TerminateGdiPlus proc
	
COMMENT	^----------------------------------------------------------------------
;PURPOSE:	delete all gdiplus objects and close gdiplus
;IN		:	n/a
;OUT	:	success	-	GpStatusOk
;		:	fail	-	one of other values in the Status enum structure
;RETURN	:	eax
comment	----------------------------------------------------------------------^
	
	.if _hGdiPlusStringFormat != NULL
		invoke GdipDeleteStringFormat,_hGdiPlusStringFormat
	.endif
	.if _hGdiPlusPen != NULL
		invoke GdipDeletePen,_hGdiPlusPen
	.endif
	.if _hGdiPlusSolidBrush != NULL
		invoke GdipDeleteBrush,_hGdiPlusSolidBrush
	.endif
	.if _hGdiPlusFont != NULL
		invoke GdipDeleteFont,_hGdiPlusFont
	.endif
	.if _hGdiPlusFontFamily != NULL
		invoke GdipDeleteFontFamily,_hGdiPlusFontFamily
	.endif
	.if _hGdiPlusGraphics != NULL
		invoke GdipDeleteGraphics,_hGdiPlusGraphics
	.endif
	
	invoke GdiplusShutdown, addr _pGdiPlusToken

	ret

TerminateGdiPlus endp
;--------------------------------------------------------------------------------

CreateGdiPlusFontFamily proc pszFontFamilyName:DWORD, hGdiPlusFontFamily:DWORD

COMMENT	^----------------------------------------------------------------------
;PURPOSE:	create gdi+ font family by given name
;IN		:	pszFontFamilyName	-	font family name
;		:	pGdiPlusFontFamily	-	pointer to hold the created font family
;OUT	:	n/a
;RETURN	:	eax
comment	----------------------------------------------------------------------^

	LOCAL	@pbuffer	:DWORD
	
	invoke AnsiToWChar,pszFontFamilyName,-1
	mov @pbuffer,eax

	invoke GdipCreateFontFamilyFromName,@pbuffer,NULL,hGdiPlusFontFamily

	invoke GlobalFree,@pbuffer
	
	ret
	
CreateGdiPlusFontFamily endp
;--------------------------------------------------------------------------------

CreateGdiPlusFont proc hFontFamily:DWORD,hFont:DWORD

COMMENT	^----------------------------------------------------------------------
;PURPOSE:	create gdi+ font by given font family name
;IN		:	hFontFamily	-	font family
;		:	hFont		-	handle to the created font
;OUT	:	n/a
;RETURN	:	n/a
comment	----------------------------------------------------------------------^

	invoke GdipCreateFont,hFontFamily,16,FontStyleRegular,UnitPoint,hFont
;	invoke FormatGdiPlusErrorMsg,eax
	
	ret
	
CreateGdiPlusFont endp
;--------------------------------------------------------------------------------

CreateGdiPlusSolidBrush proc rgbColor:DWORD,hBrush:DWORD
	
	invoke GdipCreateSolidFill,rgbColor,hBrush

	ret

CreateGdiPlusSolidBrush endp
;--------------------------------------------------------------------------------

CreateGdiPlusPenFromBrush proc pBrush:DWORD,rWidth:REAL4,pPen:DWORD
	
	invoke GdipCreatePen2,pBrush,rWidth,UnitPoint,pPen
	
	ret

CreateGdiPlusPenFromBrush endp
;--------------------------------------------------------------------------------

CreateGdiPlusStringFormat proc nAttrib:DWORD,hStrFormat:DWORD
	
	invoke GdipCreateStringFormat,nAttrib,LANG_NEUTRAL,hStrFormat
	
	ret

CreateGdiPlusStringFormat endp
;--------------------------------------------------------------------------------

CreateGdiPlusGraphics proc hWnd:DWORD
	
COMMENT	^----------------------------------------------------------------------
;PURPOSE:	create gdi+ graphics object by given window handle
;IN		:	hWnd	-	window handle
;OUT	:	n/a
;RETURN	:	eax
comment	----------------------------------------------------------------------^

	LOCAL @hdc	:DWORD
	
	invoke GdipCreateFromHWND,hWnd,addr _hGdiPlusGraphics
	invoke GetDC,hWnd
	mov @hdc,eax
	.if eax != NULL
		;invoke GdipCreateFromHDC,@hdc,addr _hGdiPlusGraphics
		invoke ReleaseDC,hWnd,@hdc
	.endif
	
	ret

CreateGdiPlusGraphics endp
;--------------------------------------------------------------------------------

MakeARGB proc nAlpha:BYTE,nColorRed:BYTE,nColorGreen:BYTE,nColorBlue:BYTE
	
	mov al,nAlpha
	shl eax,8
	or al,nColorRed
	shl eax,8
	or al,nColorGreen
	shl eax,8
	or al,nColorBlue
	
	ret

MakeARGB endp
;--------------------------------------------------------------------------------

GdiPlusDrawText proc pWStr:DWORD,nCount:DWORD,pRectF:DWORD
	
	invoke GdipDrawString,_hGdiPlusGraphics,\
						  pWStr,nCount,\
						  _hGdiPlusFont,\
						  pRectF,\
						  _hGdiPlusStringFormat,\
						  _hGdiPlusSolidBrush
	PrintHex eax
	invoke FormatGdiPlusErrorMsg,eax
	
	ret

GdiPlusDrawText endp
FormatGdiPlusErrorMsg proc nErrorCode:DWORD
	
COMMENT	^----------------------------------------------------------------------
;PURPOSE:	format gdiplus error message
;IN		:	error code
;OUT	:	success	-	pointer to error message
;		:	fail	-	NULL
;RETURN	:	eax
comment	----------------------------------------------------------------------^
	
	push esi
	mov esi,offset _pGdiPlusErrCodeMsg
	mov eax,nErrorCode
	mov eax,[esi+eax*4]
	if DBGWIN_DEBUG_ON eq 1
		push eax
		mov eax,[eax]
		PrintHex nErrorCode
		PrintStringByAddr eax
		pop eax
		mov eax,[eax+4]
		PrintStringByAddr eax
	else
		mov esi,[eax+4]
		mov eax,[eax]
		invoke MessageBoxEx,NULL,esi,eax,MB_OK or MB_ICONERROR or MB_APPLMODAL,0
	endif
	pop esi
	
	ret

FormatGdiPlusErrorMsg endp
;--------------------------------------------------------------------------------
